Crate kcr_policy_clusterpedia_io

Crate kcr_policy_clusterpedia_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the policy.clusterpedia.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

policy.clusterpedia.io/v1alpha1

  • ClusterImportPolicy
  • PediaClusterLifecycle

Modules

v1alpha1